GoogleChromeLauncher (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server.browserlaunchers
Class GoogleChromeLauncher

    java.lang.Object
      org.openqa.selenium.server.browserlaunchers.AbstractBrowserLauncher
          org.openqa.selenium.server.browserlaunchers.GoogleChromeLauncher

All Implemented Interfaces:
  BrowserLauncher

    public class GoogleChromeLauncher

extends AbstractBrowserLauncher

Browser launcher for Google Chrome.

Known issues:

- Does not support the avoidProxy command-line option.
- Does not fall back to a direct connection if the proxy fails to respond.

Field Summary

Fields inherited from class org.openqa.selenium.server.browserlaunchers.AbstractBrowserLauncher
`browserConfigurationOptions, sessionId`

Constructor Summary
`GoogleChromeLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, BrowserInstallation browserInstallation)`
`GoogleChromeLauncher(BrowserConfigurationOptions browserOptions, RemoteControlConfiguration configuration, java.lang.String sessionId, java.lang.String browserLaunchLocation)`

Method Summary
`void` | `close()` Stop (kill) the browser process
`java.lang.Process` | `getProcess()` Returns a process if there is an associated one running with this browser launcher (this is not required to be implementd).
`protected void` | `launch(java.lang.String url)`

Methods inherited from class org.openqa.selenium.server.browserlaunchers.AbstractBrowserLauncher
`getConfiguration, getPort, launchHTMLSuite, launchRemoteSession`

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

Constructor Detail

### GoogleChromeLauncher

    public GoogleChromeLauncher(BrowserConfigurationOptions browserOptions,
                                RemoteControlConfiguration configuration,
                                java.lang.String sessionId,
                                java.lang.String browserLaunchLocation)

### GoogleChromeLauncher

    public GoogleChromeLauncher(BrowserConfigurationOptions browserOptions,
                                RemoteControlConfiguration configuration,
                                java.lang.String sessionId,
                                BrowserInstallation browserInstallation)

Method Detail

### launch

    protected void launch(java.lang.String url)

  Specified by:
    `launch` in class `AbstractBrowserLauncher`

### close

    public void close()

  Description copied from interface: `BrowserLauncher`
  Stop (kill) the browser process

### getProcess

    public java.lang.Process getProcess()

  Description copied from interface: `BrowserLauncher`
  Returns a process if there is an associated one running with this browser launcher (this is not required to be implementd).

  Returns:
    a handle to a process if one is available, or null if one is not available or if no browser is running

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.